OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "無効なクラウド共有ID",
    "Server to server sharing is not enabled on this server" : "このサーバーでは、サーバー間の共有が有効ではありません",
    "Couldn't establish a federated share." : "クラウド共有を接続できませんでした。",
    "Couldn't establish a federated share, maybe the password was wrong." : "クラウド共有を接続できませんでした。パスワードが間違っていませんか。",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "クラウド共有リクエストが送信されました。招待が受信できます。通知を確認してください。",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "フェデレーション共有を確立できませんでした。連合するサーバーが古すぎます（Nextcloud <= 9）。",
    "It is not allowed to send federated group shares from this server." : "このサーバーからフェデレーショングループ共有を送信することはできません。",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "このアイテム %1$sはすでにアカウント %2$sと共有されているため、共有に失敗しました",
    "Not allowed to create a federated share to the same account" : "同じアカウントでフェデレーション共有は作成できません",
    "Federated shares require read permissions" : "フェデレーション共有には読み取り権限が必要です",
    "File is already shared with %s" : "ファイルはすでに %s と共有されています。",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "%1$s の共有に失敗しました。%2$s が見つかりませんでした。おそらくサーバーに接続できないか、自己証明書を使用しています。",
    "Could not find share" : "共有が見つかりませんでした",
    "Federated sharing" : "連携共有",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "{user} からリモート共有として {share} を受け取りました。({behalf} の代理として)",
    "You received {share} as a remote share from {user}" : "{user} から {share} のリモート共有が届いています",
    "Accept" : "承諾",
    "Decline" : "拒否",
    "Federated Cloud Sharing" : "統合されたクラウド共有",
    "Sharing" : "共有",
    "Federated file sharing" : "連携共有",
    "Provide federated file sharing across servers" : "サーバー間でフェデレーションファイル共有を提供する",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "サーバー間での共有方法を調整します。フェデレート共有を使用している場合は、このサーバーにいる人同士の共有も含まれます。",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "このサーバのユーザが他のサーバに共有を送信することを許可する (このオプションは公開共有への WebDAV アクセスも許可します)",
    "Allow people on this server to receive shares from other servers" : "このサーバーにいる人が他のサーバーから共有を受け取ることを許可する",
    "Allow people on this server to send shares to groups on other servers" : "このサーバーの人が他のサーバーのグループに共有を送信できるようにする",
    "Allow people on this server to receive group shares from other servers" : "このサーバーにいる人が他のサーバーからグループ共有を受信できるようにする",
    "Search global and public address book for people" : "グローバル・アドレス帳と公開アドレス帳を検索",
    "Allow people to publish their data to a global and public address book" : "グローバルで公開されたアドレス帳に自分のデータを公開できるようにする",
    "Unable to update federated files sharing config" : "クラウド共有設定を更新できませんでした",
    "Federated Cloud" : "クラウド共有",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Nextcloud サーバーまたはその他の Open Cloud Mesh (OCM) 互換のサーバーとサービスを使用しているユーザーであれば、共有ダイアログに Federated Cloud ID を入力するだけで誰とでも共有できます。例: person@cloud.example.com",
    "Your Federated Cloud ID:" : "あなたのクラウド共有ID：",
    "Share it so your friends can share files with you:" : "友達があなたとファイルを共有できるよう、シェアしましょう:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (旧 Twitter)",
    "Mastodon" : "Mastodon",
    "Add to your website" : "ウェブサイトに追加",
    "Share with me via Nextcloud" : "Nextcloud 経由で共有",
    "HTML Code:" : "HTMLコード:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "私の #Nextcloud Federated Cloud ID を通して共有してください、 {url} を参照してください。",
    "Share with me through my #Nextcloud Federated Cloud ID" : "#Nextcloud の「クラウド共有ID」で私と共有できます。",
    "Cloud ID copied to the clipboard" : "クリップボードにクラウドIDをコピーしました",
    "Copy to clipboard" : "クリップボードにコピー",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote} からのリモート共有 {name} を追加してもよろしいですか？",
    "Remote share" : "リモート共有",
    "Remote share password" : "リモート共有のパスワード",
    "Cancel" : "キャンセル",
    "Add remote share" : "リモート共有を追加",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "ユーザー%2$sによりすでに共有されているため%1$s を共有できませんでした。",
    "Not allowed to create a federated share with the same user" : "同じユーザーでクラウド共有は作成できません。",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "ユーザーがサーバー間で共有する方法を調整します。フェデレーション共有を使用している場合、このサーバー上のユーザー間の共有も含まれます。",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "このサーバー上のユーザーが他のサーバーに共有を送信できるようにします（このオプションでは、WebDAVがパブリック共有にアクセスすることもできます）",
    "Allow users on this server to receive shares from other servers" : "ユーザーが他のサーバーからこのサーバーに共有することを許可する",
    "Allow users on this server to send shares to groups on other servers" : "ユーザーがこのサーバーから他のサーバー上のグループに共有することを許可する",
    "Allow users on this server to receive group shares from other servers" : "ユーザーが他のサーバーからこのサーバーにグループ共有することを許可する",
    "Search global and public address book for users" : "グローバルまたはユーザーの公開アドレス帳を検索する",
    "Allow users to publish their data to a global and public address book" : "公開アドレス帳をグローバルに公開することをユーザーに許可する",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Clipboard is not available" : "クリップボードは利用できません",
    "Copied!" : "コピーしました！"
},
"nplurals=1; plural=0;");
